searchData={"items":[{"type":"module","title":"Glicko","doc":"Provides the implementation of the Glicko rating system.\n\nSee the [specification](http://www.glicko.net/glicko/glicko2.pdf) for implementation details.","ref":"Glicko.html"},{"type":"module","title":"Usage - Glicko","doc":"Get a player's new rating after a series of matches in a rating period.\n\n    iex> results = [Result.new(Player.new_v1([rating: 1400, rating_deviation: 30]), :win),\n    ...> Result.new(Player.new_v1([rating: 1550, rating_deviation: 100]), :loss),\n    ...> Result.new(Player.new_v1([rating: 1700, rating_deviation: 300]), :loss)]\n    iex> player = Player.new_v1([rating: 1500, rating_deviation: 200])\n    iex> Glicko.new_rating(player, results, [system_constant: 0.5])\n    %Player.V1{rating: 1464.0506705393013, rating_deviation: 151.51652412385727}\n\nGet a player's new rating when they haven't played within a rating period.\n\n    iex> player = Player.new_v1([rating: 1500, rating_deviation: 200])\n    iex> Glicko.new_rating(player, [], [system_constant: 0.5])\n    %Player.V1{rating: 1.5e3, rating_deviation: 200.27141669877065}\n\nCalculate the probability of a player winning against an opponent.\n\n    iex> player = Player.new_v1\n    iex> opponent = Player.new_v1\n    iex> Glicko.win_probability(player, opponent)\n    0.5\n\nCalculate the probability of a player drawing against an opponent.\n\n    iex> player = Player.new_v1\n    iex> opponent = Player.new_v1\n    iex> Glicko.draw_probability(player, opponent)\n    1.0","ref":"Glicko.html#module-usage"},{"type":"function","title":"Glicko.draw_probability/2","doc":"Calculates the probability of a player drawing against an opponent.\n\nReturns a value between `0.0` and `1.0`.","ref":"Glicko.html#draw_probability/2"},{"type":"function","title":"Glicko.draw_probability/3","doc":"Calculates the probability of a player drawing against an opponent from a player rating, opponent rating and opponent rating deviation.\n\nValues provided for the player rating, opponent rating and opponent rating deviation must be *v2* based.\n\nReturns a value between `0.0` and `1.0`.","ref":"Glicko.html#draw_probability/3"},{"type":"function","title":"Glicko.new_rating/3","doc":"Generate a new rating from an existing rating and a series (or lack) of results.\n\nReturns the updated player with the same version given to the function.","ref":"Glicko.html#new_rating/3"},{"type":"function","title":"Glicko.win_probability/2","doc":"Calculates the probability of a player winning against an opponent.\n\nReturns a value between `0.0` and `1.0`.","ref":"Glicko.html#win_probability/2"},{"type":"function","title":"Glicko.win_probability/3","doc":"Calculates the probability of a player winning against an opponent from a player rating, opponent rating and opponent rating deviation.\n\nValues provided for the player rating, opponent rating and opponent rating deviation must be *v2* based.\n\nReturns a value between `0.0` and `1.0`.","ref":"Glicko.html#win_probability/3"},{"type":"type","title":"Glicko.new_rating_opts/0","doc":"","ref":"Glicko.html#t:new_rating_opts/0"},{"type":"module","title":"Glicko.Player","doc":"Provides convenience functions that handle conversions between Glicko versions one and two.","ref":"Glicko.Player.html"},{"type":"module","title":"Usage - Glicko.Player","doc":"Create a *v1* player with the default values for an unrated player.\n\n    iex> Player.new_v1\n    %Player.V1{rating: 1.5e3, rating_deviation: 350.0}\n\nCreate a *v2* player with the default values for an unrated player.\n\n    iex> Player.new_v2\n    %Player.V2{rating: 0.0, rating_deviation: 2.014761872416068, volatility: 0.06}\n\nCreate a player with custom values.\n\n    iex> Player.new_v2(rating: 3.0, rating_deviation: 2.0, volatility: 0.05)\n    %Player.V2{rating: 3.0, rating_deviation: 2.0, volatility: 0.05}\n\nConvert a *v2* player to a *v1*. Note this drops the volatility.\n\n    iex> Player.new_v2 |> Player.to_v1\n    %Player.V1{rating: 1.5e3, rating_deviation: 350.0}\n\nConvert a *v1* player to a *v2*.\n\n    iex> Player.new_v1 |> Player.to_v2(0.06)\n    %Player.V2{rating: 0.0, rating_deviation: 2.014761872416068, volatility: 0.06}\n\nNote calling `to_v1` with a *v1* player or likewise with `to_v2` and a *v2* player\nwill pass-through unchanged. The volatility arg in this case is ignored.\n\n    iex> player_v2 = Player.new_v2\n    iex> player_v2 == Player.to_v2(player_v2)\n    true","ref":"Glicko.Player.html#module-usage"},{"type":"function","title":"Glicko.Player.initial_volatility/0","doc":"The recommended initial volatility value for a new player.","ref":"Glicko.Player.html#initial_volatility/0"},{"type":"function","title":"Glicko.Player.new_v1/1","doc":"Creates a new v1 player.\n\nIf not overriden, will use the default values for an unrated player.","ref":"Glicko.Player.html#new_v1/1"},{"type":"function","title":"Glicko.Player.new_v2/1","doc":"Creates a new v2 player.\n\nIf not overriden, will use default values for an unrated player.","ref":"Glicko.Player.html#new_v2/1"},{"type":"function","title":"Glicko.Player.rating/2","doc":"A version agnostic method for getting a player's rating.","ref":"Glicko.Player.html#rating/2"},{"type":"function","title":"Glicko.Player.rating_deviation/2","doc":"A version agnostic method for getting a player's rating deviation.","ref":"Glicko.Player.html#rating_deviation/2"},{"type":"function","title":"Glicko.Player.rating_interval/2","doc":"A convenience function for summarizing a player's strength as a 95%\nconfidence interval.\n\nThe lowest value in the interval is the player's rating minus twice the RD,\nand the highest value is the player's rating plus twice the RD.\nThe volatility measure does not appear in the calculation of this interval.\n\nAn example would be if a player's rating is 1850 and the RD is 50,\nthe interval would range from 1750 to 1950. We would then say that we're 95%\nconfident that the player's actual strength is between 1750 and 1950.\n\nWhen a player has a low RD, the interval would be narrow, so that we would\nbe 95% confident about a player’s strength being in a small interval of values.","ref":"Glicko.Player.html#rating_interval/2"},{"type":"function","title":"Glicko.Player.scale_rating_deviation_to/2","doc":"Scales a player's rating deviation.","ref":"Glicko.Player.html#scale_rating_deviation_to/2"},{"type":"function","title":"Glicko.Player.scale_rating_to/2","doc":"Scales a player's rating.","ref":"Glicko.Player.html#scale_rating_to/2"},{"type":"function","title":"Glicko.Player.to_v1/1","doc":"Converts a v2 player to a v1.\n\nA v1 player will pass-through unchanged.\n\nNote the volatility field used in a v2 player will be lost in the conversion.","ref":"Glicko.Player.html#to_v1/1"},{"type":"function","title":"Glicko.Player.to_v2/2","doc":"Converts a v1 player to a v2.\n\nA v2 player will pass-through unchanged with the volatility arg ignored.","ref":"Glicko.Player.html#to_v2/2"},{"type":"function","title":"Glicko.Player.volatility/2","doc":"A version agnostic method for getting a player's volatility.","ref":"Glicko.Player.html#volatility/2"},{"type":"type","title":"Glicko.Player.rating/0","doc":"","ref":"Glicko.Player.html#t:rating/0"},{"type":"type","title":"Glicko.Player.rating_deviation/0","doc":"","ref":"Glicko.Player.html#t:rating_deviation/0"},{"type":"type","title":"Glicko.Player.t/0","doc":"","ref":"Glicko.Player.html#t:t/0"},{"type":"type","title":"Glicko.Player.v1/0","doc":"","ref":"Glicko.Player.html#t:v1/0"},{"type":"type","title":"Glicko.Player.v2/0","doc":"","ref":"Glicko.Player.html#t:v2/0"},{"type":"type","title":"Glicko.Player.version/0","doc":"","ref":"Glicko.Player.html#t:version/0"},{"type":"type","title":"Glicko.Player.volatility/0","doc":"","ref":"Glicko.Player.html#t:volatility/0"},{"type":"module","title":"Glicko.Player.V1","doc":"","ref":"Glicko.Player.V1.html"},{"type":"type","title":"Glicko.Player.V1.t/0","doc":"","ref":"Glicko.Player.V1.html#t:t/0"},{"type":"module","title":"Glicko.Player.V2","doc":"","ref":"Glicko.Player.V2.html"},{"type":"type","title":"Glicko.Player.V2.t/0","doc":"","ref":"Glicko.Player.V2.html#t:t/0"},{"type":"module","title":"Glicko.Result","doc":"Provides convenience functions for handling a result against an opponent.","ref":"Glicko.Result.html"},{"type":"module","title":"Usage - Glicko.Result","doc":"iex> opponent = Player.new_v2\n    iex> Result.new(opponent, 1.0)\n    %Result{opponent_rating: 0.0, opponent_rating_deviation: 2.014761872416068, score: 1.0}\n    iex> Result.new(opponent, :draw) # With shortcut\n    %Result{opponent_rating: 0.0, opponent_rating_deviation: 2.014761872416068, score: 0.5}","ref":"Glicko.Result.html#module-usage"},{"type":"function","title":"Glicko.Result.new/2","doc":"Creates a new result from an opponent and score.\n\nSupports passing either `:loss`, `:draw`, or `:win` as shortcuts.","ref":"Glicko.Result.html#new/2"},{"type":"function","title":"Glicko.Result.new/3","doc":"Creates a new result from an opponent rating, opponent rating deviation and score.\n\nValues provided for the opponent rating and opponent rating deviation must be *v2* based.\n\nSupports passing either `:loss`, `:draw`, or `:win` as shortcuts.","ref":"Glicko.Result.html#new/3"},{"type":"function","title":"Glicko.Result.opponent_rating/1","doc":"Convenience function for accessing an opponent's rating.","ref":"Glicko.Result.html#opponent_rating/1"},{"type":"function","title":"Glicko.Result.opponent_rating_deviation/1","doc":"Convenience function for accessing an opponent's rating deviation.","ref":"Glicko.Result.html#opponent_rating_deviation/1"},{"type":"function","title":"Glicko.Result.score/1","doc":"Convenience function for accessing the score.","ref":"Glicko.Result.html#score/1"},{"type":"type","title":"Glicko.Result.score/0","doc":"","ref":"Glicko.Result.html#t:score/0"},{"type":"type","title":"Glicko.Result.score_shortcut/0","doc":"","ref":"Glicko.Result.html#t:score_shortcut/0"},{"type":"type","title":"Glicko.Result.t/0","doc":"","ref":"Glicko.Result.html#t:t/0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}